%Electric field transmitted through an objective.
%
% sys    System data
% out    Simulation results
%
% E      Electric field [V/m]
% k      Wavevector [rad/m]
% N      Number of samples

%Copyright  Marcel Leutenegger, 2003-2007, cole Polytechnique Fdrale de Lausanne (EPFL),
%Laboratoire d'Optique Biomdicale (LOB), BM - Station 17, 1015 Lausanne, Switzerland.
%
%    This library is free software; you can redistribute it and/or modify it under
%    the terms of the GNU Lesser General Public License as published by the Free
%    Software Foundation; version 2.1 of the License.
%
%    This library is distributed in the hope that it will be useful, but WITHOUT ANY
%    WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
%    PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
%
%    You should have received a copy of the GNU Lesser General Public License along
%    with this library; if not, write to the Free Software Foundation, Inc.,
%    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
%
function [E,k,N]=field(sys,out)
[M,N]=samples(sys,out);
[E,r,t,p,ct,st]=modifiers(sys,M,N);
if any(strat)
   [cp,sp,k]=stratified(sys,t);
else
   [cp,sp,k]=interface(sys.nm^2,sys.ns^2,sys.NA*r);
end
[tp,ts]=transmission(sys,t);
tp=tp.*cp;
ts=ts.*sp;
[cp,sp]=cis(p);
if size(E,1) > 1
   tp=tp.*(cp.*E(1,:,:) + sp.*E(2,:,:));
   ts=ts.*(sp.*E(1,:,:) - cp.*E(2,:,:));
else
   tp=tp.*cp.*E;
   ts=ts.*sp.*E;
end
ct=tp.*k/sys.ns;
E=cat(1,ct.*cp + sp.*ts,ct.*sp - cp.*ts,tp.*st/sys.ns);
k=2*pi/sys.lo*k;
E(isnan(E))=0;
